@@ -18,9 +18,8 @@
 #'
 #' @examples
 #' library(IRon)
-#' library(rpart)
 #'
-#' if(requireNamespace("rpart")) {
+#' if(requireNamespace("rpart",quietly=TRUE)) {
 #'
 #'    data(accel)
 #'
@@ -70,7 +69,7 @@ ser <- function(trues, preds, phi.trues=NULL, ph=NULL, t=0) {
 #' @param return.err Boolean to indicate if the errors at each subset of increasing relevance should be returned. Default is FALSE
 #' @param norm Normalize the SERA values for internal optimisation only (TRUE/FALSE)
 #'
-#' @importFrom scam scam
+#'
 #'
 #' @export
 #'
@@ -78,9 +77,8 @@ ser <- function(trues, preds, phi.trues=NULL, ph=NULL, t=0) {
 #'
 #' @examples
 #' library(IRon)
-#' library(rpart)
 #'
-#' if(requireNamespace("rpart")) {
+#' if(requireNamespace("rpart",quietly=TRUE)) {
 #'
 #'    #' data(accel)
 #'
@@ -108,7 +106,6 @@ ser <- function(trues, preds, phi.trues=NULL, ph=NULL, t=0) {
 sera <- function(trues, preds, phi.trues=NULL, ph=NULL, pl=FALSE,
                  m.name="Model", step=0.001, return.err=FALSE, norm=FALSE) {
 
-  requireNamespace("scam", quietly=TRUE)
   requireNamespace("ggplot2", quietly=TRUE)
 
   if(!is.data.frame(preds)) preds <- as.data.frame(preds)
@@ -137,6 +134,9 @@ sera <- function(trues, preds, phi.trues=NULL, ph=NULL, pl=FALSE,
 
   if(pl) {
 
+    # check if scam is available (as for 0.1.5 version)
+    has_scam <- requireNamespace("scam", quietly = TRUE)
+
     max_y <- max(errors)
 
     if(ncol(errors)>1) {
@@ -146,21 +146,79 @@ sera <- function(trues, preds, phi.trues=NULL, ph=NULL, pl=FALSE,
       df_melt <- reshape::melt(df,id.vars="th")
       colnames(df_melt)[2] <- "Model"
 
-      print(ggplot2::ggplot(df_melt,aes(x=th,y=.data$value,group=.data$Model,color=.data$Model)) +
-              ggplot2::geom_smooth(method="scam",formula=y ~ s(x, k = 30, bs = "mpd"),span=0.1,se=FALSE,fullrange=TRUE) +
-              ggplot2::xlab(expression("Relevance"~phi(y))) + ylab("SER") +
-              ggplot2::ggtitle("SERA") + ylim(c(0,max_y)) + ggplot2::geom_hline(yintercept=0,colour="black"))
 
 
+      gg <- ggplot2::ggplot(df_melt, ggplot2::aes(x = th, y = .data$value, group = .data$Model, color = .data$Model)) +
+        ggplot2::xlab(expression("Relevance" ~ phi(y))) +
+        ggplot2::ylab("SER") +
+        ggplot2::ggtitle("SERA") +
+        ggplot2::ylim(c(0, max_y)) +
+        ggplot2::geom_hline(yintercept = 0, colour = "black")
+
+      if (has_scam) {
+
+        scam_fun <- get("scam", envir = asNamespace("scam"))
+        gg <- gg + ggplot2::geom_smooth(method = scam_fun,
+                                        formula = y ~ s(x, k = 30, bs = "mpd"),
+                                        span = 0.1, se = FALSE, fullrange = TRUE)
+      } else {
+        gg <- gg + ggplot2::geom_smooth(method = "gam",
+                                        formula = y ~ s(x, k = 30),
+                                        se = FALSE, fullrange = TRUE)
+      }
+
+
+
+      # if (has_scam) {
+      #   print(ggplot2::ggplot(df_melt,aes(x=th,y=.data$value,group=.data$Model,color=.data$Model)) +
+      #           ggplot2::geom_smooth(method="scam",formula=y ~ s(x, k = 30, bs = "mpd"),
+      #                                span=0.1,se=FALSE,fullrange=TRUE) +
+      #           ggplot2::xlab(expression("Relevance"~phi(y))) + ylab("SER") +
+      #           ggplot2::ggtitle("SERA") + ylim(c(0,max_y)) +
+      #           ggplot2::geom_hline(yintercept=0,colour="black"))
+      # } else {
+      #
+      #   print(ggplot2::ggplot(df_melt,aes(x=th,y=.data$value,group=.data$Model,color=.data$Model)) +
+      #           ggplot2::geom_smooth(method = "gam",
+      #                       formula = y ~ s(x, k = 30),
+      #                       se = FALSE, fullrange = TRUE) +
+      #           ggplot2::xlab(expression("Relevance"~phi(y))) + ylab("SER") +
+      #           ggplot2::ggtitle("SERA") + ylim(c(0,max_y)) +
+      #           ggplot2::geom_hline(yintercept=0,colour="black"))
+      #   }
+
+      print(gg)
+
     } else {
 
       df <- data.frame(th=th,errors=errors)
 
-      print(ggplot2::ggplot(df,aes(x=th,y=errors)) +
-              ggplot2::geom_smooth(method="scam",formula=y ~ s(x, k = 30, bs = "mpd"),span=0.1,se=FALSE,colour="blue") +
-              ggplot2::xlab(expression("Relevance"~phi(y))) + ylab("SER") +
-              ggplot2::ggtitle(paste0(m.name," SERA = ",round(res,3))) + ylim(c(0,max_y))+ ggplot2::geom_hline(yintercept=0,colour="black") + ggplot2::geom_hline(yintercept=df[2,]$preds,linetype="dashed",colour="darkgrey"))
+      gg <- ggplot2::ggplot(df, ggplot2::aes(x = th, y = errors)) +
+        ggplot2::xlab(expression("Relevance" ~ phi(y))) +
+        ggplot2::ylab("SER") +
+        ggplot2::ggtitle(paste0(m.name, " SERA = ", round(res, 3))) +
+        ggplot2::ylim(c(0, max_y)) +
+        ggplot2::geom_hline(yintercept = 0, colour = "black")
 
+      if (has_scam) {
+
+        scam_fun <- get("scam", envir = asNamespace("scam"))
+        gg <- gg + ggplot2::geom_smooth(method = scam_fun,
+                                        formula = y ~ s(x, k = 30, bs = "mpd"),
+                                        span = 0.1, se = FALSE, colour = "blue")
+      } else {
+        gg <- gg + ggplot2::geom_smooth(method = "gam",
+                                        formula = y ~ s(x, k = 30),
+                                        se = FALSE, colour = "blue")
+      }
+
+      print(gg)
+
+
+      # print(ggplot2::ggplot(df,aes(x=th,y=errors)) +
+      #         ggplot2::geom_smooth(method="scam",formula=y ~ s(x, k = 30, bs = "mpd"),span=0.1,se=FALSE,colour="blue") +
+      #         ggplot2::xlab(expression("Relevance"~phi(y))) + ylab("SER") +
+      #         ggplot2::ggtitle(paste0(m.name," SERA = ",round(res,3))) + ylim(c(0,max_y))+ ggplot2::geom_hline(yintercept=0,colour="black") + ggplot2::geom_hline(yintercept=df[2,]$preds,linetype="dashed",colour="darkgrey"))
     }
 
   }
